options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'yemp-112800.dat' lrecl=25 missover DSD DLM=' ' print;
input
  R0000100
  R2117000
  R2117100
  R2117200
  R2117300
  R2117400
  R2117500
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "PUBID - YTH ID CODE 1997";
  label R2117000 = "CHK R SELFEMP, 16+ EARN $200+ WK L1 1998";
  label R2117100 = "CHK R SELFEMP, 16+ EARN $200+ WK L2 1998";
  label R2117200 = "CHK R SELFEMP, 16+ EARN $200+ WK L3 1998";
  label R2117300 = "CHK R SELFEMP, 16+ EARN $200+ WK L4 1998";
  label R2117400 = "CHK R SELFEMP, 16+ EARN $200+ WK L5 1998";
  label R2117500 = "CHK R SELFEMP, 16+ EARN $200+ WK L6 1998";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarantee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'PUBID_1997'n
  R2117000 = 'YEMP-112800.01_1998'n
  R2117100 = 'YEMP-112800.02_1998'n
  R2117200 = 'YEMP-112800.03_1998'n
  R2117300 = 'YEMP-112800.04_1998'n
  R2117400 = 'YEMP-112800.05_1998'n
  R2117500 = 'YEMP-112800.06_1998'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
value vx0f
  0='0'
  1-999='1 TO 999'
  1000-1999='1000 TO 1999'
  2000-2999='2000 TO 2999'
  3000-3999='3000 TO 3999'
  4000-4999='4000 TO 4999'
  5000-5999='5000 TO 5999'
  6000-6999='6000 TO 6999'
  7000-7999='7000 TO 7999'
  8000-8999='8000 TO 8999'
  9000-9999='9000 TO 9999'
;
value vx1f
  1='CONDITION APPLIES'
  0='CONDITION DOES NOT APPLY'
;
value vx2f
  1='CONDITION APPLIES'
  0='CONDITION DOES NOT APPLY'
;
value vx3f
  1='CONDITION APPLIES'
  0='CONDITION DOES NOT APPLY'
;
value vx4f
  1='CONDITION APPLIES'
  0='CONDITION DOES NOT APPLY'
;
value vx5f
  1='CONDITION APPLIES'
  0='CONDITION DOES NOT APPLY'
;
value vx6f
  1='CONDITION APPLIES'
  0='CONDITION DOES NOT APPLY'
;
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format R0000100 vx0f.;
  format R2117000 vx1f.;
  format R2117100 vx2f.;
  format R2117200 vx3f.;
  format R2117300 vx4f.;
  format R2117400 vx5f.;
  format R2117500 vx6f.;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format 'PUBID_1997'n vx0f.;
  format 'YEMP-112800.01_1998'n vx1f.;
  format 'YEMP-112800.02_1998'n vx2f.;
  format 'YEMP-112800.03_1998'n vx3f.;
  format 'YEMP-112800.04_1998'n vx4f.;
  format 'YEMP-112800.05_1998'n vx5f.;
  format 'YEMP-112800.06_1998'n vx6f.;
run;
*/